package Daje::Plugin::Users::Routes;
use Mojo::Base -base, -signatures;
use v5.42;

# NAME
# ====
#
# Daje::Plugin::Users::Routes - Model class
#
# SYNOPSIS
# ========
#
#       use Daje::Plugin::Users::Routes;
#
#       my $class = Daje::Plugin::Users::Routes->new();
#       $r->get('/users/api/v1/users/:users_users_pkey');
#       $r->get('/users/api/v1/users_workflow/:users_workflow_fkey');

       
#       $r->get('/users/api/v1/users_role/:users_role_fkey');

       
#       $r->get('/users/api/v1/users_lan/:users_lan_fkey');

       
#       $r->get('/users/api/v1/verification_codes/:users_verification_codes_pkey');
#       $r->get('/users/api/v1/verification_codes_users/:users_users_fkey');

       
#       $r->get('/users/api/v1/documentation/:users_documentation_pkey');
#       $r->get('/users/api/v1/documentation_users/:users_users_fkey');

       #
#
# DESCRIPTION
# ===========
#
# Daje::Plugin::Users::Routes is the standard routes
#
# METHODS
# =======
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.com
#

# This file is generated automatically by Daje Tools 2026-02-27 18:02:26.
# It will be generated by Daje Tools again.
# <!-- Autogenerated file 2026-02-27 18:02:26 -->

our $VERSION = '0.01';

sub routes($self, $app, $config) {
    my $r = $app->auth;

    $r->get('v1/users_list_all/')->to('UsersUsersList#load_all_users_users');
    $r->get('v1/users_workflow_list/:users_workflow_fkey')->to('UsersUsers#load_list_users_workflow_fkey');
    $r->get('v1/users_role_list/:authorities_role_fkey')->to('UsersUsers#load_list_authorities_role_fkey');
    $r->get('v1/users_lan_list/:languages_lan_fkey')->to('UsersUsers#load_list_languages_lan_fkey');
    $r->get('v1/verification_codes_list_all/')->to('UsersVerificationCodesList#load_all_users_verification_codes');
    $r->get('v1/verification_codes_users_list/:users_users_fkey')->to('UsersVerificationCodes#load_list_users_users_fkey');
    $r->get('v1/documentation_list_all/')->to('UsersDocumentationList#load_all_users_documentation');
    $r->get('v1/documentation_users_list/:users_users_fkey')->to('UsersDocumentation#load_list_users_users_fkey');

    $r->get('v1/users_workflow/:users_workflow_fkey')->to('UsersUsers#load_users_workflow_fkey');
    $r->get('v1/users_role/:users_role_fkey')->to('UsersUsers#load_users_role_fkey');
    $r->get('v1/users_lan/:users_lan_fkey')->to('UsersUsers#load_users_lan_fkey');    $r->get('v1/users/:users_users_pkey')->to('UsersUsers#load_users_users_pkey');
    $r->get('v1/verification_codes_users/:users_users_fkey')->to('UsersVerificationCodes#load_users_users_fkey');    $r->get('v1/verification_codes/:users_verification_codes_pkey')->to('UsersVerificationCodes#load_users_verification_codes_pkey');
    $r->get('v1/documentation_users/:users_users_fkey')->to('UsersDocumentation#load_users_users_fkey');    $r->get('v1/documentation/:users_documentation_pkey')->to('UsersDocumentation#load_users_documentation_pkey');
}

