package Daje::Plugin::Users::Languages;
use Mojo::Base -base, -signatures;
use v5.42;

# NAME
# ====
#
# Daje::Plugin::Users::Languages - Model class
#
# SYNOPSIS
# ========
#
#
#
#
# DESCRIPTION
# ===========
#
# Daje::Plugin::Users::Languages is the standard routes
#
# METHODS
# =======
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.com
#

# This file is generated automatically by Daje Tools 2026-02-27 18:02:26.
# It will be generated by Daje Tools again.
# <!-- Autogenerated file 2026-02-27 18:02:26 -->

use Daje::Helper::Languages::InsertKeys;

has 'db';

sub language($self) {

    try {
        my $tx = $self->db->begin;
        my @keys;
        push @keys, {
                plugin => 'users',
                key => 'users',
                field => 'table',
                type => 'Label',
                translation => 'Users',
                comment => 'Users of the app',
            };
          push @keys,  {
                plugin => 'users',
                key => 'users',
                field => 'workflow',
                type => 'Label',
                translation => 'Workflow',
                comment => 'This users workflow'
            };
           push @keys, {
                plugin => 'users',
                key => 'users',
                field => 'workflow',
                type => 'Tool tips',
                translation => 'This users workflow',
                comment => 'This users workflow'
            };
         
          push @keys,  {
                plugin => 'users',
                key => 'users',
                field => 'avatar',
                type => 'Label',
                translation => 'Avatar',
                comment => 'Users avatar'
            };
           push @keys, {
                plugin => 'users',
                key => 'users',
                field => 'avatar',
                type => 'Tool tips',
                translation => 'Users avatar',
                comment => 'Users avatar'
            };
         
          push @keys,  {
                plugin => 'users',
                key => 'users',
                field => 'password',
                type => 'Label',
                translation => 'Password',
                comment => 'Must be minimum 8 characters long and a mix of upper and lowercase and numbers'
            };
           push @keys, {
                plugin => 'users',
                key => 'users',
                field => 'password',
                type => 'Tool tips',
                translation => 'Must be minimum 8 characters long and a mix of upper and lowercase and numbers',
                comment => 'Must be minimum 8 characters long and a mix of upper and lowercase and numbers'
            };
         
          push @keys,  {
                plugin => 'users',
                key => 'users',
                field => 'active',
                type => 'Label',
                translation => 'Active',
                comment => 'Is user active ?'
            };
           push @keys, {
                plugin => 'users',
                key => 'users',
                field => 'active',
                type => 'Tool tips',
                translation => 'Is user active ?',
                comment => 'Is user active ?'
            };
         
          push @keys,  {
                plugin => 'users',
                key => 'users',
                field => 'mail',
                type => 'Label',
                translation => 'eMail',
                comment => 'eMail address of the user, must be a valid eMail address'
            };
           push @keys, {
                plugin => 'users',
                key => 'users',
                field => 'mail',
                type => 'Tool tips',
                translation => 'eMail address of the user, must be a valid eMail address',
                comment => 'eMail address of the user, must be a valid eMail address'
            };
         
          push @keys,  {
                plugin => 'users',
                key => 'users',
                field => 'name',
                type => 'Label',
                translation => 'Name',
                comment => 'Full name of user'
            };
           push @keys, {
                plugin => 'users',
                key => 'users',
                field => 'name',
                type => 'Tool tips',
                translation => 'Full name of user',
                comment => 'Full name of user'
            };
         
          push @keys,  {
                plugin => 'users',
                key => 'users',
                field => 'comment',
                type => 'Label',
                translation => 'Comment',
                comment => 'Comment regarding user'
            };
           push @keys, {
                plugin => 'users',
                key => 'users',
                field => 'comment',
                type => 'Tool tips',
                translation => 'Comment regarding user',
                comment => 'Comment regarding user'
            };
         
          push @keys,  {
                plugin => 'users',
                key => 'users',
                field => 'position',
                type => 'Label',
                translation => 'Position',
                comment => 'Position in the organisation'
            };
           push @keys, {
                plugin => 'users',
                key => 'users',
                field => 'position',
                type => 'Tool tips',
                translation => 'Position in the organisation',
                comment => 'Position in the organisation'
            };
         
          push @keys,  {
                plugin => 'users',
                key => 'users',
                field => 'biography',
                type => 'Label',
                translation => 'Biography',
                comment => 'Users biography'
            };
           push @keys, {
                plugin => 'users',
                key => 'users',
                field => 'biography',
                type => 'Tool tips',
                translation => 'Users biography',
                comment => 'Users biography'
            };
         
          push @keys,  {
                plugin => 'users',
                key => 'users',
                field => 'role',
                type => 'Label',
                translation => 'Role',
                comment => 'Users role, decides authorities '
            };
           push @keys, {
                plugin => 'users',
                key => 'users',
                field => 'role',
                type => 'Tool tips',
                translation => 'Users role, decides authorities ',
                comment => 'Users role, decides authorities '
            };
         
          push @keys,  {
                plugin => 'users',
                key => 'users',
                field => 'phone',
                type => 'Label',
                translation => 'Phone',
                comment => 'Users phone number'
            };
           push @keys, {
                plugin => 'users',
                key => 'users',
                field => 'phone',
                type => 'Tool tips',
                translation => 'Users phone number',
                comment => 'Users phone number'
            };
         
          push @keys,  {
                plugin => 'users',
                key => 'users',
                field => 'department',
                type => 'Label',
                translation => 'Department',
                comment => 'Department where user works'
            };
           push @keys, {
                plugin => 'users',
                key => 'users',
                field => 'department',
                type => 'Tool tips',
                translation => 'Department where user works',
                comment => 'Department where user works'
            };
         
          push @keys,  {
                plugin => 'users',
                key => 'users',
                field => 'employed',
                type => 'Label',
                translation => 'Employed',
                comment => 'Is user employed or external'
            };
           push @keys, {
                plugin => 'users',
                key => 'users',
                field => 'employed',
                type => 'Tool tips',
                translation => 'Is user employed or external',
                comment => 'Is user employed or external'
            };
         
          push @keys,  {
                plugin => 'users',
                key => 'users',
                field => 'lan',
                type => 'Label',
                translation => 'Language',
                comment => 'Users preferred language'
            };
           push @keys, {
                plugin => 'users',
                key => 'users',
                field => 'lan',
                type => 'Tool tips',
                translation => 'Users preferred language',
                comment => 'Users preferred language'
            };
         
          push @keys,  {
                plugin => 'users',
                key => 'users',
                field => 'verified',
                type => 'Label',
                translation => 'Verified',
                comment => 'Is the users eMail verified ?'
            };
           push @keys, {
                plugin => 'users',
                key => 'users',
                field => 'verified',
                type => 'Tool tips',
                translation => 'Is the users eMail verified ?',
                comment => 'Is the users eMail verified ?'
            };
         
        push @keys, {
                plugin => 'users',
                key => 'verification_codes',
                field => 'table',
                type => 'Label',
                translation => 'Verification codes',
                comment => 'Verification codes sent to users eMail address',
            };
          push @keys,  {
                plugin => 'users',
                key => 'verification_codes',
                field => 'verification_code',
                type => 'Label',
                translation => 'Verification code',
                comment => 'Verification code'
            };
           push @keys, {
                plugin => 'users',
                key => 'verification_codes',
                field => 'verification_code',
                type => 'Tool tips',
                translation => 'Verification code',
                comment => 'Verification code'
            };
         
          push @keys,  {
                plugin => 'users',
                key => 'verification_codes',
                field => 'users',
                type => 'Label',
                translation => 'User',
                comment => 'User thats connected to verification code'
            };
           push @keys, {
                plugin => 'users',
                key => 'verification_codes',
                field => 'users',
                type => 'Tool tips',
                translation => 'User thats connected to verification code',
                comment => 'User thats connected to verification code'
            };
         
        push @keys, {
                plugin => 'users',
                key => 'documentation',
                field => 'table',
                type => 'Label',
                translation => 'Any type of documentation that relates to user like CV certificates etc ',
                comment => 'Any type of documentation that relates to user like CV certificates etc ',
            };
          push @keys,  {
                plugin => 'users',
                key => 'documentation',
                field => 'document_name',
                type => 'Label',
                translation => 'Document name',
                comment => 'Name of the document'
            };
           push @keys, {
                plugin => 'users',
                key => 'documentation',
                field => 'document_name',
                type => 'Tool tips',
                translation => 'Name of the document',
                comment => 'Name of the document'
            };
         
          push @keys,  {
                plugin => 'users',
                key => 'documentation',
                field => 'users',
                type => 'Label',
                translation => 'User',
                comment => 'User document belongs to'
            };
           push @keys, {
                plugin => 'users',
                key => 'documentation',
                field => 'users',
                type => 'Tool tips',
                translation => 'User document belongs to',
                comment => 'User document belongs to'
            };
         
          push @keys,  {
                plugin => 'users',
                key => 'documentation',
                field => 'document_type',
                type => 'Label',
                translation => 'Type',
                comment => 'Document type'
            };
           push @keys, {
                plugin => 'users',
                key => 'documentation',
                field => 'document_type',
                type => 'Tool tips',
                translation => 'Document type',
                comment => 'Document type'
            };
         

        Daje::Helper::Languages::InsertKeys->new(
            db => $self->db
        )->process(
             \@keys
        );
        $tx->commit();
    } catch($e) {
        say $e;
    }
}

1;


