package Daje::Plugin::Users::Authorities;
use Mojo::Base -base, -signatures;
use v5.42;

# NAME
# ====
#
# Daje::Plugin::Users::Authorities - Model class
#
# SYNOPSIS
# ========
#
#
#
#
# DESCRIPTION
# ===========
#
# Daje::Plugin::Users::Authorities is the standard routes
#
# METHODS
# =======
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.com
#

# This file is generated automatically by Daje Tools 2026-02-27 18:02:26.
# It will be generated by Daje Tools again.
# <!-- Autogenerated file 2026-02-27 18:02:26 -->

use Daje::Helper::Authorities::InsertPluginFunction;

has 'db';

sub authorize($self) {

    try {
        my $tx = $self->db->begin;
        my @functions = (
            "users_users",
            "users_verification_codes",
            "users_documentation"
        );

        Daje::Helper::Authorities::InsertPluginFunction->new(
            db => $self->db
        )->process(
            "users", \@functions
        );
        $tx->commit();
    } catch($e) {
        say $e;
    }
}

1;

