package Daje::Controller::Users::UsersVerificationCodes;
use Mojo::Base 'Daje::Controller::Users::Super::UsersVerificationCodes', -base, -signatures;
use v5.42;

# NAME
# ====
#
# Daje::Controller::Users::UsersVerificationCodes - Controller class
#
# SYNOPSIS
# ========
#
#       use Daje::Controller::Users::UsersVerificationCodes
#
#
#
# DESCRIPTION
# ===========
#
# Daje::Controller::Users::UsersVerificationCodes is a standard controller
#
# METHODS
# =======
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.com
#

# This file is generated automatically by Daje Tools 2026-02-02 02:54:28.
# It will not be re-generated by Daje Tools again.
# <!-- Autogenerated file 2026-02-02 02:54:28 -->

our $VERSION = '0.01';

1;

