package Daje::Plugin::Users::Helpers;
use Mojo::Base -base, -signatures;
use v5.42;

# NAME
# ====
#
# Daje::Plugin::Users::Helpers - Model class
#
# SYNOPSIS
# ========
#
#       use Daje::Plugin::Users::Helpers;
#
#       my $class = Daje::Plugin::Users::Helpers->new();
#       $app->helper(
#           v_users_users => sub {
#               state  $v_users_users = Daje::Database::Model::vUsersUsers->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_users_verification_codes => sub {
#               state  $v_users_verification_codes = Daje::Database::Model::vUsersVerificationCodes->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_users_documentation => sub {
#               state  $v_users_documentation = Daje::Database::Model::vUsersDocumentation->new(db => shift->pg->db)
#        });#
#       $app->helper(
#           v_users_users_list => sub {
#               state  $v_users_users_list = Daje::Database::Model::vUsersUsersList->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_users_verification_codes_list => sub {
#               state  $v_users_verification_codes_list = Daje::Database::Model::vUsersVerificationCodesList->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_users_documentation_list => sub {
#               state  $v_users_documentation_list = Daje::Database::Model::vUsersDocumentationList->new(db => shift->pg->db)
#        });#
# DESCRIPTION
# ===========
#
# Daje::Plugin::Users::Helpers is the standard routes
#
# METHODS
# =======
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.com
#

# This file is generated automatically by Daje Tools 2026-02-27 18:02:26.
# It will be re-generated by Daje Tools again.
# <!-- Autogenerated file 2026-02-27 18:02:26 -->

use Daje::Database::View::vUsersUsers;
use Daje::Database::View::vUsersVerificationCodes;
use Daje::Database::View::vUsersDocumentation;# Lists
use Daje::Database::View::vUsersUsersList;
use Daje::Database::View::vUsersVerificationCodesList;
use Daje::Database::View::vUsersDocumentationList;

our $VERSION = '0.01';

sub helpers($self, $app, $config) {

    $app->helper(
        v_users_users => sub {
            state  $v_users_users = Daje::Database::View::vUsersUsers->new(db => shift->pg->db)
        });
    $app->helper(
        v_users_verification_codes => sub {
            state  $v_users_verification_codes = Daje::Database::View::vUsersVerificationCodes->new(db => shift->pg->db)
        });
    $app->helper(
        v_users_documentation => sub {
            state  $v_users_documentation = Daje::Database::View::vUsersDocumentation->new(db => shift->pg->db)
        });    # Lists
    $app->helper(
        v_users_users_list => sub {
            state  $v_users_users_list = Daje::Database::View::vUsersUsersList->new(db => shift->pg->db)
        });
    $app->helper(
        v_users_verification_codes_list => sub {
            state  $v_users_verification_codes_list = Daje::Database::View::vUsersVerificationCodesList->new(db => shift->pg->db)
        });
    $app->helper(
        v_users_documentation_list => sub {
            state  $v_users_documentation_list = Daje::Database::View::vUsersDocumentationList->new(db => shift->pg->db)
        });}

1;



